@@ -4,23 +4,26 @@ Episode objects are created/managed using the `pod_store.podcasts.PodcastEpisode
 class.
 """
 import os
+import re
 from datetime import datetime
 from typing import Any, List, Optional, Type, TypeVar
 
+import music_tag
 import requests
 
-from . import util
+from . import DO_NOT_SET_EPISODE_METADATA, util
 
 DOWNLOAD_CHUNK_SIZE = 2000
 
 E = TypeVar("E", bound="Episode")
+P = TypeVar("Podcast")
 
 
 class Episode:
     """Podcast episode tracked in the store.
 
+    podcast (pod_store.podcasts.Podcast): podcast this episode belongs to
     id (str): store ID (parsed from RSS feed ID)
-    download_path (str): where episode will be downloaded on file system
     episode_number (str): zero-padded episode number from podcast feed
     title (str): episode title
     short_description (str): short description of episode
@@ -36,8 +39,8 @@ class Episode:
 
     def __init__(
         self,
+        podcast: P,
         id: str,
-        download_path: str,
         episode_number: str,
         title: str,
         short_description: str,
@@ -48,8 +51,9 @@ class Episode:
         tags: List[str] = None,
         downloaded_at: Optional[datetime] = None,
     ) -> None:
+        self._podcast = podcast
+
         self.id = id
-        self.download_path = download_path
         self.episode_number = episode_number
         self.title = title
         self.short_description = short_description
@@ -93,6 +97,26 @@ class Episode:
     def __repr__(self) -> str:
         return f"Episode({self.episode_number}, {self.title})"
 
+    @property
+    def download_path(self) -> str:
+        """Determines the download path for this episode, based on the podcast's
+        download location.
+
+        The filename is built from the episode number and a lowercase version of the
+        title that has had non-alphanumeric characters replaced with a dash. This helps
+        with filename consistency and removes characters that lead to problems on some
+        device filesystems (such as the one on my cheap MP3 player).
+
+        The file type extension is determined from the download URL.
+        """
+        lowercase_title = self.title.lower()
+        cleaned_title = re.sub(r"[^a-zA-Z0-9]", "-", lowercase_title)
+        _, file_type = os.path.splitext(self.url)
+        return os.path.join(
+            self._podcast.episode_downloads_path,
+            f"{self.episode_number}-{cleaned_title}{file_type}",
+        )
+
     def download(self) -> None:
         """Download the audio file of the episode to the file system."""
         os.makedirs(os.path.dirname(self.download_path), exist_ok=True)
@@ -101,9 +125,44 @@ class Episode:
         with open(self.download_path, "wb") as f:
             for chunk in resp.iter_content(DOWNLOAD_CHUNK_SIZE):
                 f.write(chunk)
+
         self.downloaded_at = datetime.utcnow()
         self.untag("new")
 
+        self._set_audio_file_metadata(self.download_path)
+
+    def _set_audio_file_metadata(self, download_path: str) -> None:
+        """Helper to set metadata on the downloaded MP3 file.
+
+        Matches the following audio metadata tags to the values:
+
+            artist        -> episode._podcast.title
+            album_artist
+
+            title         -> episode.title
+            track_title
+
+            genre         -> "Podcast"
+
+            track_number  -> episode.episode_number
+            year          -> episode.created_at.year
+
+        Setting the `DO_NOT_SET_POD_STORE_EPISODE_METADATA` env var will stop this
+        behavior.
+        """
+        if DO_NOT_SET_EPISODE_METADATA:
+            return
+
+        f = music_tag.load_file(download_path)
+        f["artist"] = self._podcast.title
+        f["album_artist"] = self._podcast.title
+        f["title"] = self.title
+        f["track_title"] = self.title
+        f["genre"] = "Podcast"
+        f["track_number"] = self.episode_number
+        f["year"] = self.created_at.year
+        f.save()
+
     def update(self, **data: Any) -> None:
         """Update arbitrary attributes by passing in a dict."""
         for key, value in data.items():
@@ -128,7 +187,6 @@ class Episode:
 
         return {
             "id": self.id,
-            "download_path": self.download_path,
             "episode_number": self.episode_number,
             "title": self.title,
             "short_description": self.short_description,
