@@ -8,7 +8,7 @@ from typing import Any, List, Optional, Type, TypeVar
 
 import feedparser
 
-from . import util
+from . import PODCAST_DOWNLOADS_PATH, util
 from .episodes import Episode
 from .exc import EpisodeDoesNotExistError, NoEpisodesFoundError
 
@@ -19,18 +19,17 @@ class PodcastEpisodes:
     """Class for tracking all the episodes associated with a
     `pod_store.podcasts.Podcast` object.
 
-    _episodes_download_path (str): location in file system the podcast will download
-        episodes to.
+    _podcast (pod_store.Podcasts.Podcast): podcast these episodes belong to
 
     _episodes (dict):
         {id: `pod_store.episodes.Episode`}
     """
 
-    def __init__(self, episode_downloads_path: str, episode_data: dict) -> None:
-        self._episode_downloads_path = episode_downloads_path
-
+    def __init__(self, podcast: P, episode_data: dict) -> None:
+        self._podcast = podcast
         self._episodes = {
-            id: Episode.from_json(**episode) for id, episode in episode_data.items()
+            id: Episode.from_json(podcast=podcast, **episode)
+            for id, episode in episode_data.items()
         }
 
     @property
@@ -43,23 +42,15 @@ class PodcastEpisodes:
         id: str,
         episode_number: str,
         title: str,
-        download_path: str = None,
         **kwargs,
     ) -> None:
-        """Add a new episode.
-
-        Will construct a download path if none is provided, using the
-        `_episodes_download_path` property and the episode number and title passed in.
-        """
-        download_path = download_path or os.path.join(
-            self._episode_downloads_path, f"{episode_number}-{title}.mp3"
-        )
+        """Add a new episode to the store."""
         episode = Episode(
+            podcast=self._podcast,
             id=id,
             episode_number=episode_number,
             title=title,
             tags=["new"],
-            download_path=download_path,
             **kwargs,
         )
         self._episodes[id] = episode
@@ -121,7 +112,6 @@ class Podcast:
     """Podcast tracked in the store.
 
     title (str): podcast title
-    episode_downloads_path (str): location in file system to download podcast episodes
     feed (str): RSS feed URL
     tags (list): arbitrary text tags assigned to the podcast
 
@@ -137,7 +127,6 @@ class Podcast:
     def __init__(
         self,
         title: str,
-        episode_downloads_path: str,
         feed: str,
         episode_data: dict,
         tags: List[str] = None,
@@ -147,15 +136,12 @@ class Podcast:
         tags = tags or []
 
         self.title = title
-        self.episode_downloads_path = episode_downloads_path
         self.feed = feed
         self.tags = tags
         self.created_at = created_at or datetime.utcnow()
         self.updated_at = updated_at or datetime.utcnow()
 
-        self.episodes = PodcastEpisodes(
-            episode_data=episode_data, episode_downloads_path=episode_downloads_path
-        )
+        self.episodes = PodcastEpisodes(podcast=self, episode_data=episode_data)
 
     @classmethod
     def from_json(
@@ -179,6 +165,15 @@ class Podcast:
     def __repr__(self) -> str:
         return f"Podcast({self.title!r})"
 
+    @property
+    def episode_downloads_path(self) -> str:
+        """Determine the download path for podcast episodes.
+
+        Builds the file path from the `POD_STORE_PODCASTS_DOWNLOAD_PATH` env var
+        configuration (defaults to /home/<username>/Podcasts) and the podcast title.
+        """
+        return os.path.join(PODCAST_DOWNLOADS_PATH, self.title)
+
     @property
     def has_new_episodes(self) -> bool:
         """Inidicates if the podcast has any new episodes."""
@@ -186,7 +181,7 @@ class Podcast:
 
     @property
     def number_of_new_episodes(self) -> int:
-        return len(self.episodes.list(downloaded_at=None))
+        return len(self.episodes.list(new=True))
 
     def refresh(self) -> None:
         """Refresh the episode data tracked in the pod store for this podcast.
@@ -244,7 +239,6 @@ class Podcast:
         updated_at = util.parse_datetime_to_json(self.updated_at)
         return {
             "title": self.title,
-            "episode_downloads_path": self.episode_downloads_path,
             "feed": self.feed,
             "tags": self.tags,
             "created_at": created_at,
@@ -280,7 +274,7 @@ class Podcast:
         """
         id = self._parse_store_episode_id(id)
         long_description = self._strip_html_and_non_ascii_characters(summary)
-        url = [u["href"] for u in links if u["type"] in ("audio/mpeg", "audio/mp3")][0]
+        url = self._get_download_url(links)
         published_parsed = datetime(*published_parsed[:6])
 
         if subtitle:
@@ -288,9 +282,7 @@ class Podcast:
         else:
             short_description = long_description
 
-        episode_number = itunes_episode or self._parse_episode_number_from_rss_title(
-            title
-        )
+        episode_number = itunes_episode
 
         if updated_parsed:
             updated_parsed = datetime(*updated_parsed[:6])
@@ -318,28 +310,24 @@ class Podcast:
         return rss_id.split("/")[-1]
 
     @staticmethod
-    def _parse_episode_number_from_rss_title(rss_title: str) -> str:
-        """Try to get an episode number from the episode title in the RSS feed.
+    def _strip_html_and_non_ascii_characters(text: str) -> str:
+        """Strip HTML tags and non-ASCII characters from RSS feed data."""
+        return re.sub("<[^<]+?>", "", text.encode("ascii", "ignore").decode("utf-8"))
 
-        Sometimes episode titles start or end with an episode number.
+    @staticmethod
+    def _get_download_url(links: List[dict]) -> str:
+        """Determines the download link for the episode audio from the RSS links data.
 
-        This may be a very bad idea.
+        Prefers ogg format, otherwise selects the first audio link available.
         """
-        stripped_title = re.sub(r"[^A-Za-z0-9 ]+", "", rss_title)
-        title_tokens = stripped_title.split()
-        start_token, end_token = title_tokens[0], title_tokens[-1]
-
-        if start_token.isdigit():
-            return start_token
-        elif end_token.isdigit():
-            return end_token
+        download_urls = []
+        for audio_link in [al for al in links if al["type"].startswith("audio/")]:
+            if audio_link["type"] == "audio/ogg":
+                return audio_link["href"]
+            download_urls.append(audio_link["href"])
+        return download_urls[0]
 
     @staticmethod
     def _pad_episode_number(episode_number: str) -> str:
         """Create an episode number padded with up to 3 zeros."""
         return episode_number.rjust(4, "0")
-
-    @staticmethod
-    def _strip_html_and_non_ascii_characters(text: str) -> str:
-        """Strip HTML tags and non-ASCII characters from RSS feed data."""
-        return re.sub("<[^<]+?>", "", text.encode("ascii", "ignore").decode("utf-8"))
